==> libpappsomspp_0.11.8.orig.tar.gz: libpappsomspp-0.11.8/src/cli/mzcbor2mzmlcli.h <==
/**
 * \file mzcbor2mzmlcli.h
 * \date 04/12/2025
 * \author Olivier Langella
 * \brief CLI tool to convert mzCBOR to mzML
 */


/*******************************************************************************
 * Copyright (c) 2025 Olivier Langella <Olivier.Langella@universite-paris-saclay.fr>.
 *
 * This file is part of the PAPPSOms++ library.
 *
 *     PAPPSOms++ is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     PAPPSOms++ is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with PAPPSOms++.  If not, see <http://www.gnu.org/licenses/>.
 *
 ******************************************************************************/


#pragma once

#include <QDebug>

#include <QObject>
#include <QCoreApplication>
#include "pappsomspp/config.h"

class Mzcbor2MzmlCli : public QObject
{
  Q_OBJECT
  public:
  /**
   * Default constructor
   */
  explicit Mzcbor2MzmlCli(QObject *parent = 0);

  /**
   * Destructor
   */
  virtual ~Mzcbor2MzmlCli();
  /////////////////////////////////////////////////////////////
  /// Call this to quit application
  /////////////////////////////////////////////////////////////
  void quit();

  signals:
  /////////////////////////////////////////////////////////////
  /// Signal to finish, this is connected to Application Quit
  /////////////////////////////////////////////////////////////
  void finished();

  public slots:
  /////////////////////////////////////////////////////////////
  /// This is the slot that gets called from main to start everything
  /// but, everthing is set up in the Constructor
  /////////////////////////////////////////////////////////////
  void run();

  /////////////////////////////////////////////////////////////
  /// slot that get signal when that application is about to quit
  /////////////////////////////////////////////////////////////
  void aboutToQuitApp();

  private:
  QCoreApplication *app;
};

==> libpappsomspp_0.11.9.orig.tar.gz: libpappsomspp-0.11.9/src/cli/mzcbor2mzmlcli.h <==
/**
 * \file mzcbor2mzmlcli.h
 * \date 04/12/2025
 * \author Olivier Langella
 * \brief CLI tool to convert mzCBOR to mzML
 */


/*******************************************************************************
 * Copyright (c) 2025 Olivier Langella <Olivier.Langella@universite-paris-saclay.fr>.
 *
 * This file is part of the PAPPSOms++ library.
 *
 *     PAPPSOms++ is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     PAPPSOms++ is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with PAPPSOms++.  If not, see <http://www.gnu.org/licenses/>.
 *
 ******************************************************************************/


#pragma once

#include <QDebug>

#include <QObject>
#include <QCoreApplication>
#include <QFileInfo>
#include "pappsomspp/config.h"
#include "pappsomspp/core/processing/uimonitor/uimonitorinterface.h"

class Mzcbor2MzmlCli : public QObject
{
  Q_OBJECT
  public:
  /**
   * Default constructor
   */
  explicit Mzcbor2MzmlCli(QObject *parent = 0);

  /**
   * Destructor
   */
  virtual ~Mzcbor2MzmlCli();
  /////////////////////////////////////////////////////////////
  /// Call this to quit application
  /////////////////////////////////////////////////////////////
  void quit();

  signals:
  /////////////////////////////////////////////////////////////
  /// Signal to finish, this is connected to Application Quit
  /////////////////////////////////////////////////////////////
  void finished();

  public slots:
  /////////////////////////////////////////////////////////////
  /// This is the slot that gets called from main to start everything
  /// but, everthing is set up in the Constructor
  /////////////////////////////////////////////////////////////
  void run();

  /////////////////////////////////////////////////////////////
  /// slot that get signal when that application is about to quit
  /////////////////////////////////////////////////////////////
  void aboutToQuitApp();

  private:
  void convertAllMzcborInDir(pappso::UiMonitorInterface &monitor,
                             const QFileInfo &input_dir,
                             const QString &output_str);

  private:
  QCoreApplication *app;
};
